@@ -568,7 +568,7 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
                               "LookupError in deactivate event; clearing focus")
                 orca.setLocusOfFocus(event, None)
                 orca_state.activeWindow = None
-            return
+                return
             debug.printException(debug.LEVEL_WARNING)
             debug.println(debug.LEVEL_WARNING,
                           "LookupError above while processing event: %s" %\
@@ -834,6 +834,10 @@ class FocusTrackingPresenter(presentation_manager.PresentationManager):
             except:
                 pass
 
+            script = self.getScript(
+                event.host_application or event.source.getApplication())
+            script.eventCache[event.type] = (event, time.time())
+
         if event:
             if settings.debugEventQueue:
                 debug.println(debug.LEVEL_ALL,
