@@ -33,12 +33,18 @@ import Queue
 import threading
 import time
 
-import bonobo
-import ORBit
+_gnomespeechAvailable = False
 
-# Init the ORB if we need to.  With AT-SPI/CORBA, we depend upon the pyatspi
-# implementation to init the ORB for us.  [[[WDW: With AT-SPI/D-Bus, we need
-# to do it ourselves.  I'm not sure how to ask ORBit itself if it's been
+try:
+    import bonobo
+    import ORBit
+    _gnomespeechAvailable = True
+except:
+    pass
+
+# Init the ORB if we need to. With AT-SPI/CORBA, we depend upon the pyatspi
+# implementation to init the ORB for us. [[[WDW: With AT-SPI/D-Bus, we need
+# to do it ourselves. I'm not sure how to ask ORBit itself if it's been
 # init'ed yet, so I do so indirectly by looking for an attribute of pyatspi.
 # This attribute has been set if AT-SPI/CORBA is in use and it not set if
 # AT-SPI/D-Bus is in use.]]]
@@ -47,7 +53,8 @@ try:
     import pyatspi
     poa = pyatspi.Accessibility__POA
 except AttributeError:
-    orb = ORBit.CORBA.ORB_init()
+    if _gnomespeechAvailable:
+        orb = ORBit.CORBA.ORB_init()
 
 import chnames
 import debug
@@ -192,6 +199,9 @@ class SpeechServer(speechserver.SpeechServer):
 
     def __activateDriver(iid):
 
+        if not _gnomespeechAvailable:
+            return None
+
         # We know what we are doing here, so tell pylint not to flag
         # the _narrow method call as a warning.  The disable-msg is
         # localized to just this method.
@@ -245,8 +255,10 @@ class SpeechServer(speechserver.SpeechServer):
         # Get a list of all the drivers on the system and find out how many
         # of them work.
         #
-        knownServers = bonobo.activation.query(
-            "repo_ids.has('IDL:GNOME/Speech/SynthesisDriver:0.3')")
+        knownServers = []
+        if _gnomespeechAvailable:
+            knownServers = bonobo.activation.query(
+                "repo_ids.has('IDL:GNOME/Speech/SynthesisDriver:0.3')")
 
         for server in knownServers:
             if server.iid not in SpeechServer.__activeServers:
@@ -264,6 +276,9 @@ class SpeechServer(speechserver.SpeechServer):
         See SpeechServer.getInfo() for more info.
         """
 
+        if not _gnomespeechAvailable:
+            return None
+
         if info and info[1] in SpeechServer.__activeServers:
             return SpeechServer.__activeServers[info[1]]
 
@@ -750,7 +765,8 @@ class SpeechServer(speechserver.SpeechServer):
         """
         chname = chnames.getCharacterName(character)
         if orca_state.activeScript and orca_state.usePronunciationDictionary:
-            chname = orca_state.activeScript.adjustForPronunciation(chname)
+            chname = orca_state.activeScript.\
+                utilities.adjustForPronunciation(chname)
         self.speak(chname, acss)
 
     def speakUtterances(self, utterances, acss=None, interrupt=True):
@@ -904,6 +920,14 @@ class SpeechServer(speechserver.SpeechServer):
 
         return newText
 
+    def updatePunctuationLevel(self):
+        """ Punctuation level changed, inform this speechServer. """
+
+        # We dont need to do anything, __addVerbalizedPunctuation
+        # already does this work for us.
+        #
+        pass
+
     def __speak(self, text=None, acss=None, interrupt=True):
         """Speaks all queued text immediately.  If text is not None,
         it is added to the queue before speaking.
@@ -941,6 +965,11 @@ class SpeechServer(speechserver.SpeechServer):
 
         text = self.__addVerbalizedPunctuation(text)
 
+        # Replace no break space characters with plain spaces since some
+        # synthesizers cannot handle them.  See bug #591734.
+        #
+        text = text.decode("UTF-8").replace(u'\u00a0', ' ').encode("UTF-8")
+
         try:
             # [[[TODO: WDW - back this stop out for now.  The problem is
             # that we end up clipping too much speech, especially in the
@@ -956,8 +985,8 @@ class SpeechServer(speechserver.SpeechServer):
             # On failure, remember what we said, reset our connection to the
             # speech synthesis driver, and try to say it again.
             #
-            debug.printException(debug.LEVEL_SEVERE)
-            debug.println(debug.LEVEL_SEVERE, "Restarting speech...")
+            debug.printException(debug.LEVEL_WARNING)
+            debug.println(debug.LEVEL_WARNING, "Restarting speech...")
             self.reset()
             return -1
 
@@ -978,7 +1007,7 @@ class SpeechServer(speechserver.SpeechServer):
         if self.__sayAll:
             self.stop()
 
-        if not acss and text and text.isupper():
+        if not acss and text and text.decode("UTF-8").isupper():
             try:
                 acss = \
                     orca_state.activeScript.voices[settings.UPPERCASE_VOICE]
@@ -1182,8 +1211,10 @@ class SpeechServer(speechserver.SpeechServer):
         speakers = self.__speakers
         self.shutdown()
 
-        servers = bonobo.activation.query(
-            "repo_ids.has('IDL:GNOME/Speech/SynthesisDriver:0.3')")
+        servers = []
+        if _gnomespeechAvailable:
+            servers = bonobo.activation.query(
+                "repo_ids.has('IDL:GNOME/Speech/SynthesisDriver:0.3')")
 
         for server in servers:
             if server.iid == self.__iid:
